runit_measureSimulate from the unit measurement model density function for each unit
# S4 method for spatPomp
vec_rmeasure(object, x, times, params, ...)An array of dimension length(unit_names(object)) by dim(x)[2] by dim(x)[3]
representing each unit's simulated measurement assessed for each replicate in x for each observation time.
a spatPomp object
numeric; state at which measurements are simulated
numeric; time at which measurements are simulated
numeric; parameter set at which measurements are simulated
additional parameters will be ignored
Kidus Asfaw