- code
encodes a component of a spatiotemporal POMP model using C code
- method
a character string matching the name of the 'spatPomp'
argument which the code is designed to specify. This argument is ignored unless
needed to correctly specify the Csnippet.
- unit_statenames
a subset of the unit_statenames slot of
the spatPomp object for which we are writing a model. This argument
allows the user to get variables that can be indexed conveniently to update
states and measurements in a loop. See examples for more details.
- unit_obsnames
a subset of the unit_obsnames slot of
the spatPomp object for which we are writing a model. This argument
allows the user to get variables that can be indexed conveniently to update
states and measurements in a loop. See examples for more details.
- unit_covarnames
if the model has covariate information for each unit,
the names of the covariates for each unit can be supplied to this argument.
This allows the user to get variables that can be indexed conveniently to
use incorporate the covariate information in a loop. See examples for more
details.
- unit_ivpnames
This argument is particularly useful when specifying the
rinit model component. The paramnames argument to the
spatPomp() constructor often has names for initial value
parameters for the latent states (e.g. S1_0, S2_0 for the
the quantity of susceptibles at unit 1 and unit 2 at the initial time in an
SIR model). By supplying unit_ivpnames, we can get variables
that can be easily indexed to reference the initial value parameters (in
the previous example, unit_ivpnames=c('S') we can get a variable
named S_0 that we can index as S_0[0] and S_0[1] to
refer to S1_0 and S2_0). See examples for more details.
- unit_paramnames
This argument is particularly useful when there
are non-initial value parameters that are unit-specific.
- unit_vfnames
This argument is particularly useful when specifying the
skeleton model component. For all components of the latent state,
the user can assume a variable defining the time-derivative is pre-defined (e.g.
DS1 and DS2 for the time-derivative of the quantity of the
susceptibles at unit 1 and unit 2 in an SIR model). By supplying
unit_vfnames, we can get variables that can be easily indexed to
reference these variables (in the previous example,
setting unit_vfnames=c('S') gets us a variable
named DS that we can index as DS[0] and DS[1] to
refer to DS1 and DS2). See examples for more details.